/*This script file reports the 25%, 50%, and 75% quantiles of the distribution of student/school-choice level driving times (pooling over the four school years in the sample)*/
/*This script file also reports the percentage of students attending schools within the 25%, 50%, and 75% quantiles of the distribution of student/school-choice level driving times (pooling over the four school years in the sample)*/

clear all
set more off
set mem 40g


global path = "D:\Dropbox\SCP\data\"

/*Creating the student/school choice data-set for each school year in Stata format*/
foreach i in 04 05 06 07{
	insheet using "${path}utilityData`i'.csv", comma clear
	rename v1 choiceRep
	rename v2 grade
	rename v3 indAttended
	rename v4 FRL
	rename v5 raceBlack
	rename v6 raceOther
	rename v7 moving_costs
	rename v8 drivingTimes
	rename v9 group
	rename v10 ability_index
	rename v11 ind_ability
	rename v16 net_income
	rename v17 gradeMin
	rename v18 gradeMax
	rename v19 randsid2
	rename v20 magnetapplied
	rename v21 oversubscribed
	rename v22 everGifted
	rename v23 allSchools
	rename v24 female
	rename v25 inflowInd
	rename v26 ALAind
	rename v27 closedInd
	rename v28 everSpecEd
	rename v29 offenses
	rename v30 susp_days
	save "${path}utilityData`i'_4.dta", replace
}

clear

/*Stacking the four student/school-choice level data-sets corresponding to different school years*/
append using "${path}utilityData04_4.dta" "${path}utilityData05_4.dta" "${path}utilityData06_4.dta" "${path}utilityData07_4.dta", generate(year)

/*Creating the driving time for the school the student actually attends in each year*/
bysort randsid2 year: egen dtattend = total(drivingTimes*indAttended)

/*Fixing driving times for the leave district outside option*/
replace drivingTimes = dtattend if choiceRep==92

/*Dropping schools that a student can't attend (ex: a4th grader can't attend a middle school)*/
keep if grade<=gradeMax
keep if grade>=gradeMin
drop if drivingTimes==5000000

gen constant = 1

sum drivingTimes, d
gen dt25 = `r(p25)'
gen dt50 = `r(p50)'
gen dt75 = `r(p75)'

by randsid2 year: gen count_obs = _n
keep if count_obs==1

gen indAttend25 = dtattend<=dt25
gen indAttend50 = dtattend<=dt50
gen indAttend75 = dtattend<=dt75

sum dt* indAttend*
