clc
clear

%%Run this script file in order to estimate the first-stage, student demand model excluding both school/school-year fixed effects and random coefficients. 

%%Setting file path and moving to that directory
path2 = 'D:/Dropbox/SCP/';
cd(strcat(path2,'/code/first_stage_school_demand/nofe_full/'));

%%%Reading in Student/School-Year Level Data-Set
utilityData04 =csvread(strcat(path2,'/data/utilityData04.csv'),0,0);
utilityData05 =csvread(strcat(path2,'/data/utilityData05.csv'),0,0);
utilityData06 =csvread(strcat(path2,'/data/utilityData06.csv'),0,0);
utilityData07 =csvread(strcat(path2,'/data/utilityData07.csv'),0,0);

randsid = sort(unique([utilityData04(:,19); utilityData05(:,19); utilityData06(:,19); utilityData07(:,19)]));

T = max(size(randsid));

group04 = unique(sort(utilityData04(:,19)));
group05 = unique(sort(utilityData05(:,19)));
group06 = unique(sort(utilityData06(:,19)));
group07 = unique(sort(utilityData07(:,19)));

choiceSet04 = sort(unique(utilityData04(utilityData04(:,3)==1,1)));
choiceSet05 = sort(unique(utilityData05(utilityData05(:,3)==1,1)));
choiceSet06 = sort(unique(utilityData06(utilityData06(:,3)==1,1)));
choiceSet07 = sort(unique(utilityData07(utilityData07(:,3)==1,1)));

J04 = max(size(choiceSet04));
J05 = max(size(choiceSet05));
J06 = max(size(choiceSet06));
J07 = max(size(choiceSet07));
J = J04 + J05+J06+J07;


%%Adding school suspensions data to peer characteristics data
schoolQuality04 = csvread(strcat(path2,'/data/schoolQuality04.csv'),1,0);
schoolQuality05 = csvread(strcat(path2,'/data/schoolQuality05.csv'),1,0);
schoolQuality06 = csvread(strcat(path2,'/data/schoolQuality06.csv'),1,0);
schoolQuality07 = csvread(strcat(path2,'/data/schoolQuality07.csv'),1,0);

school_bev04 = csvread(strcat(path2,'/data/school_bev204.csv'),0,0);
school_bev05 = csvread(strcat(path2,'/data/school_bev205.csv'),0,0);
school_bev06 = csvread(strcat(path2,'/data/school_bev206.csv'),0,0);
school_bev07 = csvread(strcat(path2,'/data/school_bev207.csv'),0,0);

schoolQuality04 = sortrows(schoolQuality04,1);
schoolQuality05 = sortrows(schoolQuality05,1);
schoolQuality06 = sortrows(schoolQuality06,1);
schoolQuality07 = sortrows(schoolQuality07,1);

school_susp04 = sortrows(school_bev04(ismember(school_bev04(:,1),choiceSet04),:),1);
school_susp05 = sortrows(school_bev05(ismember(school_bev05(:,1),choiceSet05),:),1);
school_susp06 = sortrows(school_bev06(ismember(school_bev06(:,1),choiceSet06),:),1);
school_susp07 = sortrows(school_bev07(ismember(school_bev07(:,1),choiceSet07),:),1);

[A index04] = unique(school_susp04(:,1),'first');
[A index05] = unique(school_susp05(:,1),'first');
[A index06] = unique(school_susp06(:,1),'first');
[A index07] = unique(school_susp07(:,1),'first');

schoolQuality04 = [schoolQuality04(ismember(schoolQuality04(:,1),choiceSet04),:) school_susp04(index04,2)];
schoolQuality05 = [schoolQuality05(ismember(schoolQuality05(:,1),choiceSet05),:) school_susp05(index05,2)];
schoolQuality06 = [schoolQuality06(ismember(schoolQuality06(:,1),choiceSet06),:) school_susp06(index06,2)];
schoolQuality07 = [schoolQuality07(ismember(schoolQuality07(:,1),choiceSet07),:) school_susp07(index07,2)];

%%Estimating Panel-Data Student Demand Model for Schools without fixed effects or random coefficients
wrapper = @(gamma)datamerge(gamma,utilityData04,utilityData05,utilityData06,utilityData07,schoolQuality04,schoolQuality05,schoolQuality06,schoolQuality07,J04,J05,J06,J07);

options=optimset(optimset(@fminunc),'LargeScale','off','Display','iter','GradObj','on','MaxFunEvals',100000,'MaxIter',100000,'TolX',1e-20,'TolFun',1e-20,'DerivativeCheck','off','FinDiffType','central');

gamma0 = ones(23,1);

[gamma,fval,exitflag,output,grad,hess] = fminunc(wrapper,gamma0,options);

dlmwrite(strcat(path2,'/results/fval_nofe.txt'),fval);
dlmwrite(strcat(path2,'/results/gammaDynamic_nofe.txt'),gamma);
dlmwrite(strcat(path2,'/results/exitflag_nofe.txt'),exitflag);


%%Creating Hessian-based Standard Errors
inv_hess2 = pinv(hess) *T;

std_error3 = sqrt(diag(inv_hess2)/T);

dlmwrite(strcat(path2,'/results/std_error_nofe.txt'),std_error3);
