function [regressors2,varMat2,choiceInd2,responseMatrix2] = yeardata_setup(utilityData,gamma,schoolQuality,groupRand,randsidGroup,DTQ);
%%%This script outputs the regressors, matrix of potential school choices, and matrix of observed school choices
%%%       for a given school year in the format required by the estimation code.
%%%rows correspond to students while columns correspond to schools.

%%Sorting the data:  VERY NECESSARY FOR THE RESHAPE TRICK I DO BELOW
[B,newIndex] = sortrows(utilityData,[19 1]);
utilityData = utilityData(newIndex,:);

clear B newIndex

%%Only using choices that students attend
choiceSet = sort(unique(utilityData(utilityData(:,3)==1,1)));
utilityData = utilityData(ismember(utilityData(:,1),choiceSet),:);

schoolQuality = schoolQuality(ismember(schoolQuality(:,1),choiceSet),:);

[B,newIndex] = sortrows(schoolQuality,1);
schoolQuality = schoolQuality(newIndex,:);
school_FRL = schoolQuality(:,2);
school_Black = schoolQuality(:,3);
school_Ability = schoolQuality(:,4);
school_MHHV = schoolQuality(:,5);
school_susp = schoolQuality(:,6);

school_Ability(school_Ability==0) = -2;

%%Reading in variables
choiceRep = utilityData(:,1);
grade = utilityData(:,2);
indAttended = utilityData(:,3);
FRL = utilityData(:,4);
raceBlack = utilityData(:,5);
raceOther = utilityData(:,6);
moving_costs = utilityData(:,7);
drivingTimes = utilityData(:,8);
group = utilityData(:,9);
ability_index = utilityData(:,10);
ind_ability = utilityData(:,11);
net_income = utilityData(:,16);
gradeMin = utilityData(:,17);
gradeMax = utilityData(:,18);
randsid2 = utilityData(:,19);
magnetapplied = utilityData(:,20);
oversubscribed = utilityData(:,21);
everGifted = utilityData(:,22);
allSchools = utilityData(:,23);
female = utilityData(:,24);
inflowInd = utilityData(:,25);
ALAind = utilityData(:,26);
closedInd = utilityData(:,27);
everSpecEd = utilityData(:,28);
offenses = utilityData(:,29);
susp_days = utilityData(:,30);

%%SCALING NET INCOME
net_income = net_income/10000;

T = sum(choiceRep==92);
J = max(size(unique(choiceRep)));

response2 = choiceRep(indAttended==1);
responseMatrix = zeros(T,J);

A = unique(choiceRep);
for j=1:J
    responseMatrix(:,j) = (response2==A(j));
end

%%%Fix regressors to be TxJ each
net_income = reshape(net_income,J,T);
net_income = net_income';

raceBlack = reshape(raceBlack,J,T);
raceBlack = raceBlack';

FRL = reshape(FRL,J,T);
FRL = FRL';

ind_ability = reshape(ind_ability,J,T);
ind_ability = ind_ability';

travel_costs = reshape(drivingTimes,J,T);
travel_costs = travel_costs';

everGifted = reshape(everGifted,J,T);
everGifted = everGifted';

everSpecEd = reshape(everSpecEd,J,T);
everSpecEd = everSpecEd';

indAttended = reshape(indAttended,J,T);
indAttended = indAttended';

leaveInd = zeros(T,J);
leaveInd(:,J) = 1;

moving_costs = reshape(moving_costs,J,T);
moving_costs = moving_costs';

offenses = reshape(offenses,J,T);
offenses = offenses';

susp_days = reshape(susp_days,J,T);
susp_days = susp_days';

school_FRL = repmat(reshape(school_FRL,J,1),1,T);
school_FRL = school_FRL';

school_Black = repmat(reshape(school_Black,J,1),1,T);
school_Black = school_Black';

school_Ability = repmat(reshape(school_Ability,J,1),1,T);
school_Ability = school_Ability';

school_MHHV = repmat(reshape(school_MHHV,J,1),1,T);
school_MHHV = school_MHHV';

school_susp = repmat(reshape(school_susp,J,1),1,T);
school_susp = school_susp';

%Creating unavailable schools in a year, restricting choice set based on driving times
indUnavail = (travel_costs==5000000) | ((travel_costs>DTQ) & responseMatrix==0);
travel_costs = travel_costs + (travel_costs==5000000) * (-5000000)+ (travel_costs==5000000)*(1.1*max(drivingTimes(drivingTimes~=5000000)));

%%Creating gradeMin and gradeMax to further restrict the choice set by grade
gradeMin(gradeMin==1) = 0;
gradeMinInd = (gradeMin>grade);
gradeMinInd = reshape(gradeMinInd,J,T);
gradeMinInd = gradeMinInd';

gradeMaxInd = (gradeMax<grade);
gradeMaxInd = reshape(gradeMaxInd,J,T);
gradeMaxInd = gradeMaxInd';

grade = reshape(grade,J,T);
grade = grade';

%%These variables aren't used in the current version of the estimation, but can be constructed and used if desired
privateInd=0;
school_Gifted=0;
school_SpecEd=0;

clear utilityData

%Setting up variables to integrate over the random coefficients using quadrature
R1 = 9;
R2 = 9;  %matlabpool number
R = R1*R2;
nDim = 4;  %Number of random coefficients to integrate over
acc = 4;  %Will be exact for polynomials up to 2*acc - 1 

[nodes, weights] = nwspgr('KPN',nDim,acc);  %This is for normal weights as needed, not Gaussian weights (checked moments)

nodes1 = nodes(:,1);
nodes2 = nodes(:,2);
nodes3 = nodes(:,3);
nodes4 = nodes(:,4);

f2 = @(beta)randLogQuadYearNum_setup(beta,nodes1,nodes2,nodes3,nodes4,weights,responseMatrix,net_income,raceBlack,FRL,school_FRL,school_Black,school_Ability,ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,school_susp,T,J,R1,R2);
[regressors,varMat,choiceInd] = f2(gamma);

clear net_income raceBlack FRL school_FRL school_Black school_Ability ind_ability moving_costs travel_costs gradeMinInd gradeMaxInd indUnavail privateInd leaveInd grade everGifted everSpecEd susp_days school_Gifted school_SpecEd school_susp
clear ALAind ability_index allSchools choiceRep closedInd drivingTimes female gradeMin gradeMax group indAttended inflowInd magnetapplied offenses oversubscribed raceOther randsid2 school_MHHV

T2 = max(size(randsidGroup));
k = max(size(gamma));

%%Replacing for students in sample
regressors2 = ones(T2,J,k-J-4);

regressors2(ismember(randsidGroup,groupRand),:,:) = regressors;
clear regressors

varMat2 = ones(T2,J,R,4);
varMat2(ismember(randsidGroup,groupRand),:,:,:) = varMat;
clear varMat

choiceInd2 = ones(T2,J);
choiceInd2(ismember(randsidGroup,groupRand),:) = choiceInd;
clear choiceInd

responseMatrix2 = zeros(T2,J);
responseMatrix2(ismember(randsidGroup,groupRand),:) = responseMatrix;
responseMatrix2(~ismember(randsidGroup,groupRand),1) = 1; %%Make all of the students not in this school-year (ex: already graduated from the 8th grade in 2005-06) choose school 1 (just as a device to get sum(probLog.*responseMatrix) to equal one)
clear responseMatrix
end