function [negSimLik,gradient] = datamergeRand_noinitial(gamma,regressors,varMat,choiceInd,responseMatrix,group04,group05,group06,group07,randsid,T,J04,J05,J06,J07,R1,R2);
%%This script file aggregates the conditinal probabilities for each of the four schools years, integrating over the random coefficients
%%The end result is calculating the negative loglikelihood and gradient

%%%Reading in quadrature-based approach to integrating over the random coefficients
R = R1*R2;
nDim = 4;  %Number of random coefficients to integrate over
acc = 4;  %Will be exact for polynomials up to 2*acc - 1 

[nodes, weights] = nwspgr('KPN',nDim,acc);  %This is for normal weights as needed, not Gaussian weights (checked moments)

%%Initializing number of school options, number of parameters, etc.
J = J04 + J05 + J06 + J07;

size_gamma = max(size(gamma));
numReg=size_gamma-J;
numRegP1=size_gamma-J+1;

%%Creating conditional probabilities for each year and value of the random coefficients; these probability matrices are T x J x R
%%I am over summing the years that the student doesn't attend by making responseMatrix =1 for one school in those years
probLog = cell(4,1);

probLog04 = yeardata5(gamma,regressors{1},varMat{1},choiceInd{1},responseMatrix{1},group04,randsid,T,J,J04,0,R1,R2);
probLog{1} = probLog04;

probLog05 = yeardata5(gamma,regressors{2},varMat{2},choiceInd{2},responseMatrix{2},group05,randsid,T,J,J05,J04,R1,R2);
probLog{2} = probLog05;

probLog06 = yeardata5(gamma,regressors{3},varMat{3},choiceInd{3},responseMatrix{3},group06,randsid,T,J,J06,J04+J05,R1,R2);
probLog{3} = probLog06;

probLog07 = yeardata5(gamma,regressors{4},varMat{4},choiceInd{4},responseMatrix{4},group07,randsid,T,J,J07,J04+J05+J06,R1,R2);
probLog{4} = probLog07;

%%Multiplying out the conditional probabilities for the four schools years, multiplying by the probability weight for each random coefficient value, and calculating the negative log-likelihood
probSim = squeeze(sum(probLog{1}.*repmat(responseMatrix{1},[1 1 R]),2)).*squeeze(sum(probLog{2}.*repmat(responseMatrix{2},[1 1 R]),2)).*squeeze(sum(probLog{3}.*repmat(responseMatrix{3},[1 1 R]),2)).*squeeze(sum(probLog{4}.*repmat(responseMatrix{4},[1 1 R]),2));

probSim = sum(bsxfun(@times,probSim,reshape(weights,[1 R])),2);

negSimLik = -sum(log(probSim));

clearvars -except size_gamma numRegP1 negSimLik gamma responseMatrix regressors varMat choiceInd weights probLog probSim group04 group05 group06 group07 randsid J04 J05 J06 J07

%%%%%%%%%%%%%%%%%%%%%%%%Creating gradient%%%%%%%%%%%%%%%%%%%%%%
gradient = -gradient_create2(gamma,responseMatrix,regressors,varMat,choiceInd,weights,probLog,probSim,group04,group05,group06,group07,randsid,J04,J05,J06,J07);
gradient(24:27) = sign(gamma(24:27)).*gradient(24:27);
end