%%%%%%%%This is the script file to run to estimate the first-stage, student-level demand model for schools 
%%%%%%%%%with school-year fixed effects and random coefficients 

clc
clear

%%Setting file path and moving to this directory
path = 'D:/Dropbox/SCP/';
cd(strcat(path,'/code/first_stage_school_demand/rand_full/'));


%%Reading in student/school choice level data for each school year
utilityData04 =csvread(strcat(path,'/data/utilityData04.csv'),0,0);
utilityData05 =csvread(strcat(path,'/data/utilityData05.csv'),0,0);
utilityData06 =csvread(strcat(path,'/data/utilityData06.csv'),0,0);
utilityData07 =csvread(strcat(path,'/data/utilityData07.csv'),0,0);

randsid = sort(unique([utilityData04(:,19); utilityData05(:,19); utilityData06(:,19); utilityData07(:,19)]));

T = max(size(randsid));

group04 = unique(sort(utilityData04(:,19)));
group05 = unique(sort(utilityData05(:,19)));
group06 = unique(sort(utilityData06(:,19)));
group07 = unique(sort(utilityData07(:,19)));

%%%%%%%%%%%%%%%%Subsetting only to those observations with no initial condition%%%%%%%%%%%%%%
randnoinitial =  data_no_initial(utilityData04,utilityData05,utilityData06,utilityData07,group04,group05,group06,group07,randsid);
utilityData04 = utilityData04(ismember(utilityData04(:,19),randnoinitial),:);
utilityData05 = utilityData05(ismember(utilityData05(:,19),randnoinitial),:);
utilityData06 = utilityData06(ismember(utilityData06(:,19),randnoinitial),:);
utilityData07 = utilityData07(ismember(utilityData07(:,19),randnoinitial),:);

randsid = sort(unique([utilityData04(:,19); utilityData05(:,19); utilityData06(:,19); utilityData07(:,19)]));
T = max(size(randsid));

group04 = unique(sort(utilityData04(:,19)));
group05 = unique(sort(utilityData05(:,19)));
group06 = unique(sort(utilityData06(:,19)));
group07 = unique(sort(utilityData07(:,19)));

choiceSet04 = sort(unique(utilityData04(utilityData04(:,3)==1,1)));
choiceSet05 = sort(unique(utilityData05(utilityData05(:,3)==1,1)));
choiceSet06 = sort(unique(utilityData06(utilityData06(:,3)==1,1)));
choiceSet07 = sort(unique(utilityData07(utilityData07(:,3)==1,1)));

J04 = max(size(choiceSet04));
J05 = max(size(choiceSet05));
J06 = max(size(choiceSet06));
J07 = max(size(choiceSet07));
J = J04 + J05+J06+J07;

%%Adding school susupensions and offenses to schoolQuality
schoolQuality04 = csvread(strcat(path,'/data/schoolQuality04.csv'),1,0);
schoolQuality05 = csvread(strcat(path,'/data/schoolQuality05.csv'),1,0);
schoolQuality06 = csvread(strcat(path,'/data/schoolQuality06.csv'),1,0);
schoolQuality07 = csvread(strcat(path,'/data/schoolQuality07.csv'),1,0);

school_bev04 = csvread(strcat(path,'/data/school_bev204.csv'),0,0);
school_bev05 = csvread(strcat(path,'/data/school_bev205.csv'),0,0);
school_bev06 = csvread(strcat(path,'/data/school_bev206.csv'),0,0);
school_bev07 = csvread(strcat(path,'/data/school_bev207.csv'),0,0);

schoolQuality04 = sortrows(schoolQuality04,1);
schoolQuality05 = sortrows(schoolQuality05,1);
schoolQuality06 = sortrows(schoolQuality06,1);
schoolQuality07 = sortrows(schoolQuality07,1);

school_susp04 = sortrows(school_bev04(ismember(school_bev04(:,1),choiceSet04),:),1);
school_susp05 = sortrows(school_bev05(ismember(school_bev05(:,1),choiceSet05),:),1);
school_susp06 = sortrows(school_bev06(ismember(school_bev06(:,1),choiceSet06),:),1);
school_susp07 = sortrows(school_bev07(ismember(school_bev07(:,1),choiceSet07),:),1);

[A index04] = unique(school_susp04(:,1),'first');
[A index05] = unique(school_susp05(:,1),'first');
[A index06] = unique(school_susp06(:,1),'first');
[A index07] = unique(school_susp07(:,1),'first');

schoolQuality04 = [schoolQuality04(ismember(schoolQuality04(:,1),choiceSet04),:) school_susp04(index04,2)];
schoolQuality05 = [schoolQuality05(ismember(schoolQuality05(:,1),choiceSet05),:) school_susp05(index05,2)];
schoolQuality06 = [schoolQuality06(ismember(schoolQuality06(:,1),choiceSet06),:) school_susp06(index06,2)];
schoolQuality07 = [schoolQuality07(ismember(schoolQuality07(:,1),choiceSet07),:) school_susp07(index07,2)];
gamma0 = ones(23 + 4 + J,1);

clearvars -except gamma0 utilityData04 utilityData05 utilityData06 utilityData07 schoolQuality04 schoolQuality05 schoolQuality06 schoolQuality07 choiceSet04 choiceSet05 choiceSet06 choiceSet07 group04 group05 group06 group07 randsid T J04 J05 J06 J07

%%Putting the data in the "cell-based" format required for the estimation code
[regressors,responseMatrix,varMat,choiceInd] = datamergeRand_setup(gamma0,utilityData04,utilityData05,utilityData06,utilityData07,schoolQuality04,schoolQuality05,schoolQuality06,schoolQuality07,choiceSet04,choiceSet05,choiceSet06,choiceSet07,group04,group05,group06,group07,randsid);

R1 = 9;
R2 = 9;  %matlabpool number

clearvars -except gamma0 regressors varMat choiceInd responseMatrix group04 group05 group06 group07 randsid T J04 J05 J06 J07 R1 R2

%%%%Estimating the model
f1 = @(gamma)datamergeRand_noinitial(gamma,regressors,varMat,choiceInd,responseMatrix,group04,group05,group06,group07,randsid,T,J04,J05,J06,J07,R1,R2);

options=optimset('Algorithm','sqp','LargeScale','off','Display','iter','GradObj','on','MaxFunEvals',100000,'MaxIter',100000,'TolX',1e-10,'TolFun',1e-10,'DerivativeCheck','off','FinDiffType','central');

[gamma,fval,exitflag,output,~,hessian]= fminunc(f1,gamma0,options);

dlmwrite(strcat(path,'/results/fval_noinitial.txt'),fval);
dlmwrite(strcat(path,'/results/gammaDynamic_noinitial.txt'),gamma);
dlmwrite(strcat(path,'/results/exitflag_noinitial.txt'),exitflag);

%%Hessian-based standard errors
std_error5 = sqrt(diag(inv(hessian./T))./T);

dlmwrite(strcat(path,'/results/std_error_noinitial.txt'),std_error5);