function [neglogLik,gradient] = condLogEst(gamma,responseMatrix,net_income,raceBlack,FRL,school_FRL,school_Black,school_Ability,ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,school_susp,T,J);
%%This script simply calculates the negative log-likelihood and gradient for the conditional logit model


%individual covariates: achievement, raceBlack, FRL, suspensions
%school characteristics: school suspensions, school_Achievement, school_Black, school_FRL
%vary by both: moving_costs, travel_costs
%%T = number of individuals
%%J = number of alternatives
%%k = number of regressors
%%parameters = J x 1 vector of initial parameter values
%%responseMatrix = T x J matrix with 1 for alternative chosen (for each row)
%%regressors= T x J x k matrix of regressors 


k = max(size(gamma));
regressors = zeros(T,J,k-J);

regressors(:,:,1) = school_Ability.*ability;
regressors(:,:,2) = school_Ability.*raceBlack;
regressors(:,:,3) = school_Ability.*FRL;
regressors(:,:,4) = school_Black.*ability;
regressors(:,:,5) = school_Black.*raceBlack;
regressors(:,:,6) = school_Black.*FRL;
regressors(:,:,7) = school_FRL.*ability;
regressors(:,:,8) = school_FRL.*raceBlack;
regressors(:,:,9) = school_FRL.*FRL;
regressors(:,:,10) = school_FRL.*susp_days;
regressors(:,:,11) = school_susp.*ability;
regressors(:,:,12) = school_susp.*raceBlack;
regressors(:,:,13) = school_susp.*FRL;
regressors(:,:,14) = school_susp.*susp_days;
regressors(:,:,15) = moving_costs;
regressors(:,:,16) = moving_costs.*ability;
regressors(:,:,17) = moving_costs.*raceBlack;
regressors(:,:,18) = moving_costs.*FRL;
regressors(:,:,19) = moving_costs.*susp_days;
regressors(:,:,20) = travel_costs;
regressors(:,:,21) = travel_costs.*ability;
regressors(:,:,22) = travel_costs.*raceBlack;
regressors(:,:,23) = travel_costs.*FRL;

v = squeeze(sum(bsxfun(@times,regressors,reshape(gamma(1:(k-J)),[1 1 k-J])),3)) + repmat(reshape(gamma((k-J+1):k),[1 J]),[T 1]);

v = exp(v);
v = v.*(1-gradeMinInd).*(1-gradeMaxInd).*(1-indUnavail);

denom = sum(v,2);  %denom is Tx1
denomMatrix = repmat(denom,[1 J]); %denomMatrix is TxJ

prob = v./denomMatrix;

prob(prob==0) = 10^(-40);
probResponse = log(prob).*responseMatrix;

neglogLik = -sum(sum(probResponse));  %%NEEDS TO BE MINIMIZED

gradient = zeros(k,1);

for i=1:(k-J)
	gradient(i) = -sum(sum(regressors(:,:,i).*(responseMatrix-prob)));
end

for i=(k-J+1):k
	fixed_effect = zeros(T,J);
	fixed_effect(:,i-k+J) = 1;
	gradient(i) = -sum(sum(fixed_effect.*(responseMatrix-prob)));
end