function [neglogLik,gradient] = condLogFull_FE_closed_shadow(gamma,beta_second_stage,residuals,raceBlack,FRL,school_FRL,school_Black,school_Ability,ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,school_susp,shadow_price,weight_schools_mat,T,J,probLogActual,index);
%%This script calculates the objective function and gradient correpsonding to the squared difference
%%between conditonal probabilities based on observed peer characteristics and those calculated by the sorting eqm. algorithm
%%The goal is to find shadow prices such that the conditional probailities and peer characteristics are mutually consistent with a sorting eqm.

%individual covariates: achievement, raceBlack, FRL, suspensions
%school characteristics: school suspensions, school_Achievement, school_Black, school_FRL
%vary by both: moving_costs, travel_costs
%%T = number of individuals
%%J = number of alternatives
%%k = number of regressors
%%parameters = J x 1 vector of initial parameter values
%%responseMatrix = T x J matrix with 1 for alternative chosen (for each row)
%%regressors= T x J x k matrix of regressors 

%%Inputting non-zero shadow prices
numshadow =sum(index);
shadow_price2 = zeros(J,1);
shadow_price2(index==1) = shadow_price;
shadow_price = shadow_price2;

k = max(size(gamma));
regressors = zeros(T,J,k-J);

regressors(:,:,1) = school_Ability.*ability;
regressors(:,:,2) = school_Ability.*raceBlack;
regressors(:,:,3) = school_Ability.*FRL;
regressors(:,:,4) = school_Black.*ability;
regressors(:,:,5) = school_Black.*raceBlack;
regressors(:,:,6) = school_Black.*FRL;
regressors(:,:,7) = school_FRL.*ability;
regressors(:,:,8) = school_FRL.*raceBlack;
regressors(:,:,9) = school_FRL.*FRL;
regressors(:,:,10) = school_FRL.*susp_days;
regressors(:,:,11) = school_susp.*ability;
regressors(:,:,12) = school_susp.*raceBlack;
regressors(:,:,13) = school_susp.*FRL;
regressors(:,:,14) = school_susp.*susp_days;
regressors(:,:,15) = moving_costs;
regressors(:,:,16) = moving_costs.*ability;
regressors(:,:,17) = moving_costs.*raceBlack;
regressors(:,:,18) = moving_costs.*FRL;
regressors(:,:,19) = moving_costs.*susp_days;
regressors(:,:,20) = travel_costs;
regressors(:,:,21) = travel_costs.*ability;
regressors(:,:,22) = travel_costs.*raceBlack;
regressors(:,:,23) = travel_costs.*FRL;

elem = (gradeMin==0) & (gradeMax==5);
middle = (gradeMin==6) & (gradeMax==8);

school_chars = [reshape(school_FRL(1,:),[J 1]) reshape(school_Black(1,:),[J 1]) reshape(school_Ability(1,:),[J 1]) reshape(school_susp(1,:),[J 1]) ones(J,1) reshape(middle(1,:),[J 1])];

v = bsxfun(@plus,reshape(sum(bsxfun(@times,regressors,reshape(gamma(1:(k-J)),[1 1 k-J])),3),[T J]),reshape(school_chars*beta_second_stage + residuals - shadow_price,[1 J]));

v = exp(v);
v = v.*(1-gradeMinInd).*(1-gradeMaxInd).*(1-indUnavail);
v = v.*weight_schools_mat;

denom = sum(v,2);  %denom is Tx1

prob = bsxfun(@times,v,1./denom);
prob(isnan(prob)) = 0;

%%Minimizing the difference between calculated probability and actual probabiity (calculated using observed peer characteristics and zero shadow prices)
objfunc = prob - probLogActual;
neglogLik = 0.5*sum(sum(objfunc.^2)); 

%%Calculating the gradient for the aforementioned objective function
gradient = zeros(numshadow,1);

temp = objfunc.*prob;
index2 = find(index==1);
for k=1:numshadow
	i = index2(k);
	fixed_effect = zeros(T,J);
	fixed_effect(:,i) = objfunc(:,i);
	gradient(k) = -sum(sum(bsxfun(@times,prob(:,i),fixed_effect - temp)));
end
gradient(isnan(gradient)) = 0;