function [c,ceq,dc,dceq] = cons_loop_closed_shadow(gamma,beta_second_stage,residuals,responseMatrix,net_income,raceBlack,FRL,school_FRL,school_Black,school_Ability,ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,school_susp,shadow_price,weight_schools_mat,T,J,capacity_68,index);
%%This script creates the school-level capacity constraints (for public schools, school-level capacity must be greater than school-level enrollment)

%individual covariates: achievement, raceBlack, FRL, suspensions
%school characteristics: school suspensions, school_Achievement, school_Black, school_FRL
%vary by both: moving_costs, travel_costs
%%T = number of individuals
%%J = number of alternatives
%%k = number of regressors
%%parameters = J x 1 vector of initial parameter values
%%responseMatrix = T x J matrix with 1 for alternative chosen (for each row)
%%regressors= T x J x k matrix of regressors 

%%Inputting non-zero shadow prices
numshadow = sum(index);
shadow_price2 = zeros(J,1);
shadow_price2(index==1) = shadow_price;
shadow_price = shadow_price2;


%%Constructing the conditional-logit based enrollments at each school
k = max(size(gamma));
regressors = zeros(T,J,k-J);

regressors(:,:,1) = school_Ability.*ability;
regressors(:,:,2) = school_Ability.*raceBlack;
regressors(:,:,3) = school_Ability.*FRL;
regressors(:,:,4) = school_Black.*ability;
regressors(:,:,5) = school_Black.*raceBlack;
regressors(:,:,6) = school_Black.*FRL;
regressors(:,:,7) = school_FRL.*ability;
regressors(:,:,8) = school_FRL.*raceBlack;
regressors(:,:,9) = school_FRL.*FRL;
regressors(:,:,10) = school_FRL.*susp_days;
regressors(:,:,11) = school_susp.*ability;
regressors(:,:,12) = school_susp.*raceBlack;
regressors(:,:,13) = school_susp.*FRL;
regressors(:,:,14) = school_susp.*susp_days;
regressors(:,:,15) = moving_costs;
regressors(:,:,16) = moving_costs.*ability;
regressors(:,:,17) = moving_costs.*raceBlack;
regressors(:,:,18) = moving_costs.*FRL;
regressors(:,:,19) = moving_costs.*susp_days;
regressors(:,:,20) = travel_costs;
regressors(:,:,21) = travel_costs.*ability;
regressors(:,:,22) = travel_costs.*raceBlack;
regressors(:,:,23) = travel_costs.*FRL;

elem = (gradeMin==0) & (gradeMax==5);
middle = (gradeMin==6) & (gradeMax==8);

school_chars = [reshape(school_FRL(1,:),[J 1]) reshape(school_Black(1,:),[J 1]) reshape(school_Ability(1,:),[J 1]) reshape(school_susp(1,:),[J 1]) ones(J,1) reshape(middle(1,:),[J 1])];

v = squeeze(sum(bsxfun(@times,regressors,reshape(gamma(1:(k-J)),[1 1 k-J])),3)) + repmat(reshape(school_chars*beta_second_stage + residuals - shadow_price,[1 J]),[T 1]);

v = exp(v);
v = v.*(1-gradeMinInd).*(1-gradeMaxInd).*(1-indUnavail);
v = v.*weight_schools_mat;

denom = sum(v,2);  %denom is Tx1
denomMatrix = repmat(denom,[1 J]); %denomMatrix is TxJ

prob = v./denomMatrix;
prob(isnan(prob)) = 0;

%%Creating school-level enrollment<=capacity constraints
c =  sum(prob(:,capacity_68~=5e6),1)' - reshape(capacity_68(capacity_68~=5e6),[sum(capacity_68~=5e6),1]) + 1;
c(index(capacity_68~=5e6)==1) = c(index(capacity_68~=5e6)==1)-1;

%%Calculating gradient of the school-level enrollment<=capacity constraints
dc = zeros(J,numshadow);

index2 = find(index==1);
for m = 1:numshadow
	k = index2(m);
    probtemp = repmat(prob(:,k),[1 J]);
    temp = zeros(T,J);
    temp(:,k) = 1;
    gradtemp = -probtemp.*prob + temp.*prob;
    dc(:,m) = dc(:,m) - sum(gradtemp)';
end

dc = dc(capacity_68~=5e6,:)'; 
dc(isnan(dc)) = 0;

%%%Setting equality constraints (and their gradients) to be empty
ceq=[];
dceq=[];

end