function probLogBaseline = dataread_NFP_closed_int_full2(weight_schools,utilityData,gamma,beta_second_stage,residuals,schoolQuality,capacity,capClosed,theta_temp);
%%This script outputs the conditional probabilities resulting from solving for a sorting eqm. for a specific set of schools closed and a specific set of intital values for the shadow prices and peer characteristics


%%Sorting the data:  VERY NECESSARY FOR THE RESHAPE TRICK I DO BELOW
[B,newIndex] = sortrows(utilityData,[9 1]);
utilityData = utilityData(newIndex,:);

%%Only using choices that students attend
choiceSet = sort(unique(utilityData(utilityData(:,3)==1,1)));
utilityData = utilityData(ismember(utilityData(:,1),choiceSet),:);
schoolQuality = schoolQuality(ismember(schoolQuality(:,1),choiceSet),:);

%%Reading in school-level data
[B,newIndex] = sortrows(schoolQuality,1);
schoolQuality = schoolQuality(newIndex,:);
school_FRL = schoolQuality(:,2);
school_Black = schoolQuality(:,3);
school_Ability = schoolQuality(:,4);
school_susp = schoolQuality(:,5);

%%Reading in student/school-year level data
choiceRep = utilityData(:,1);
grade = utilityData(:,2);
indAttended = utilityData(:,3);
FRL = utilityData(:,4);
raceBlack = utilityData(:,5);
raceOther = utilityData(:,6);
moving_costs = utilityData(:,7);
drivingTimes = utilityData(:,8);
group = utilityData(:,9);
ability_index = utilityData(:,10);
ind_ability = utilityData(:,11);
net_income = utilityData(:,16);
gradeMin = utilityData(:,17);
gradeMax = utilityData(:,18);
randsid2 = utilityData(:,19);
magnetapplied = utilityData(:,20);
oversubscribed = utilityData(:,21);
everGifted = utilityData(:,22);
allSchools = utilityData(:,23);
female = utilityData(:,24);
inflowInd = utilityData(:,25);
ALAind = utilityData(:,26);
closedInd = utilityData(:,27);
everSpecEd = utilityData(:,28);
offenses = utilityData(:,29);
susp_days = utilityData(:,30);

%%Scaling net income
net_income = net_income/10000;
%net_income = net_income - min(net_income) +0.1;
%drivingTimes = drivingTimes/100;
%ind_ability = ind_ability/100;
%school_Ability = school_Ability/100;

T = sum(choiceRep==92);
J = max(size(unique(choiceRep)));

response2 = choiceRep(indAttended==1);
responseMatrix = zeros(T,J);

A = unique(choiceRep);
for j=1:J
    responseMatrix(:,j) = (response2==A(j));
end

%%%Fix regressors to be TxJ each
net_income = reshape(net_income,J,T);
net_income = net_income';

raceBlack = reshape(raceBlack,J,T);
raceBlack = raceBlack';

FRL = reshape(FRL,J,T);
FRL = FRL';

ind_ability = reshape(ind_ability,J,T);
ind_ability = ind_ability';

travel_costs = reshape(drivingTimes,J,T);
travel_costs = travel_costs';

everGifted = reshape(everGifted,J,T);
everGifted = everGifted';

everSpecEd = reshape(everSpecEd,J,T);
everSpecEd = everSpecEd';

indAttended = reshape(indAttended,J,T);
indAttended = indAttended';

leaveInd = zeros(T,J);
leaveInd(:,J) = 1;

moving_costs = reshape(moving_costs,J,T);
moving_costs = moving_costs';

offenses = reshape(offenses,J,T);
offenses = offenses';

susp_days = reshape(susp_days,J,T);
susp_days = susp_days';

%%Creating gradeMin and gradeMax to restrict the choice set
gradeMin(gradeMin==1) = 0;
gradeMinInd = (gradeMin>grade);
gradeMinInd = reshape(gradeMinInd,J,T);
gradeMinInd = gradeMinInd';

gradeMaxInd = (gradeMax<grade);
gradeMaxInd = reshape(gradeMaxInd,J,T);
gradeMaxInd = gradeMaxInd';

gradeMin = reshape(gradeMin,J,T);
gradeMin = gradeMin';

gradeMax = reshape(gradeMax,J,T);
gradeMax = gradeMax';

grade = reshape(grade,J,T);
grade = grade';

%Creating unavailable schools in a year
indUnavail = travel_costs==5000000;
travel_costs = travel_costs + (travel_costs==5000000) * (-5000000)+ (travel_costs==5000000)*(1.1*max(drivingTimes(drivingTimes~=5000000)));

%%These variables aren't used in the current version of the estimation, but can be constructed and used if desired
privateInd=0;
school_Gifted=0;
school_SpecEd=0;

%%%Iterative process to solve for a sorting equilibrium for a given school closing scenario
max_iter = 5000;

school_FRL = schoolQuality(:,2);
school_Black = schoolQuality(:,3);
school_Ability = schoolQuality(:,4);
school_susp = schoolQuality(:,5);

%Weighting each peer characteristic to make them comparable
range_FRL = max(school_FRL) - min(school_FRL)
range_Black = max(school_Black) - min(school_Black)
range_Ability = max(school_Ability) - min(school_Ability)
range_susp = max(school_susp) - min(school_susp)

%Initial values for the shadow prices and peer characteristics
shadow_price = theta_temp(1:J);
school_FRL = theta_temp(J + (1:J));
school_Black = theta_temp(2*J + (1:J));
school_Ability = theta_temp(3*J + (1:J));
school_susp = theta_temp(4*J + (1:J));

%Initial conditional logit probabilities
probLogActual = condLogFull_closed(gamma,beta_second_stage,residuals,responseMatrix,net_income,raceBlack,FRL,repmat(reshape(school_FRL,[1 J]),[T 1]),repmat(reshape(school_Black,[1 J]),[T 1]),repmat(reshape(school_Ability,[1 J]),[T 1]),ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,repmat(reshape(school_susp,[1 J]),[T 1]),shadow_price,repmat(weight_schools,[T 1]),T,J);

weight_schools = reshape(weight_schools,[1 J]);
school_FRL_new2 = reshape(school_FRL,[1 J]).*weight_schools;
school_Black_new2 = reshape(school_Black,[1 J]).*weight_schools;
school_Ability_new2= reshape(school_Ability,[1 J]).*weight_schools;
school_susp_new2= reshape(school_susp,[1 J]).*weight_schools;

capacity = reshape(capacity,[1 J]);

probLogActual = condLogFull_closed(gamma,beta_second_stage,residuals,responseMatrix,net_income,raceBlack,FRL,repmat(reshape(school_FRL_new2,[1 J]),[T 1]),repmat(reshape(school_Black_new2,[1 J]),[T 1]),repmat(reshape(school_Ability_new2,[1 J]),[T 1]),ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,repmat(reshape(school_susp_new2,[1 J]),[T 1]),shadow_price,repmat(weight_schools,[T 1]),T,J);
tol = 10;
max_tol = 1e-5;
iter = 0;

options=optimset('Algorithm','interior-point','LargeScale','off','Display','iter','GradObj','on','GradConstr','on','MaxFunEvals',10000,'MaxIter',1000,'TolX',1e-5,'TolFun',1e-5,'DerivativeCheck','off','FinDiffType','central','TolCon',1e-5);

index = ones(1,J);
index(J) = 0;

shadow_price = zeros(J,1);
while((tol>max_tol) && (iter<=max_iter))
    school_FRL_new = school_FRL_new2;
    school_Black_new = school_Black_new2;
    school_Ability_new = school_Ability_new2;
    school_susp_new = school_susp_new2; 

	%%Calculating shadow prices by:
	%%Minimizing the difference between calculated probability and actual probabiity (calculated using observed peer characteristics and zero shadow prices)
    %%Subject to school-level capacity constraints 
    f = @(shadow_price)condLogFull_FE_closed_shadow(gamma,beta_second_stage,residuals,raceBlack,FRL,repmat(reshape(school_FRL_new2,[1 J]),[T 1]),repmat(reshape(school_Black_new2,[1 J]),[T 1]),repmat(reshape(school_Ability_new2,[1 J]),[T 1]),ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,repmat(reshape(school_susp_new2,[1 J]),[T 1]),shadow_price,repmat(weight_schools,[T 1]),T,J,probLogActual,index);    
    cons = @(shadow_price)cons_loop_closed_shadow(gamma,beta_second_stage,residuals,responseMatrix,net_income,raceBlack,FRL,repmat(reshape(school_FRL_new2,[1 J]),[T 1]),repmat(reshape(school_Black_new2,[1 J]),[T 1]),repmat(reshape(school_Ability_new2,[1 J]),[T 1]),ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,repmat(reshape(school_susp_new2,[1 J]),[T 1]),shadow_price,repmat(weight_schools,[T 1]),T,J,capacity,index);

    [shadow_price,~,exitflag] = fmincon(f,shadow_price(index==1),[],[],[],[],[],[],cons,options); 
	
    shadow_price2 = zeros(J,1);
    shadow_price2(index==1) = shadow_price;
    shadow_price = shadow_price2;

	%Recalculating probabilities based on the new shadow prices and peer characteristics based on these new probabilities	
	probLogBaseline = condLogFull_closed(gamma,beta_second_stage,residuals,responseMatrix,net_income,raceBlack,FRL,repmat(reshape(school_FRL_new,[1 J]),[T 1]),repmat(reshape(school_Black_new,[1 J]),[T 1]),repmat(reshape(school_Ability_new,[1 J]),[T 1]),ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,repmat(reshape(school_susp_new,[1 J]),[T 1]),shadow_price,repmat(weight_schools,[T 1]),T,J);

	school_FRL_new2 = sum(probLogBaseline.*FRL,1)./sum(probLogBaseline,1);
	school_Black_new2 = sum(probLogBaseline.*raceBlack,1)./sum(probLogBaseline,1);
	school_Ability_new2= sum(probLogBaseline.*ind_ability,1)./sum(probLogBaseline,1);
	school_susp_new2= sum(probLogBaseline.*susp_days,1)./sum(probLogBaseline,1);
	
	school_FRL_new2(isnan(school_FRL_new2)) = 0;
	school_Black_new2(isnan(school_Black_new2)) = 0;
	school_Ability_new2(isnan(school_Ability_new2)) = 0;
	school_susp_new2(isnan(school_susp_new2)) = 0;
	
    tol1 = max(abs(reshape(school_FRL_new,[1 J]) - reshape(school_FRL_new2,[1 J])))./range_FRL;
    tol2 = max(abs(reshape(school_Black_new,[1 J]) - reshape(school_Black_new2,[1 J]))./range_Black);
    tol3 = max(abs(reshape(school_Ability_new,[1 J]) - reshape(school_Ability_new2,[1 J])))./range_Ability;
    tol4 = max(abs(reshape(school_susp_new,[1 J]) - reshape(school_susp_new2,[1 J])))./range_susp;
    tol5 = max(sum(probLogBaseline,1) - capacity);
	tol = max([tol1;tol2;tol3;tol4;tol5]);
	
	tol
    iter = iter+1
end
end