function [negloglik,gradient] = dataread_est(utilityData,gamma,schoolQuality);
%%%This script file calculates the negative log-likelihood and gradient used to estimate the conditional logit model

%%Sorting the data:  VERY NECESSARY FOR THE RESHAPE TRICK I DO BELOW
[B,newIndex] = sortrows(utilityData,[9 1]);
utilityData = utilityData(newIndex,:);

%%Only using choices that students attend
choiceSet = sort(unique(utilityData(utilityData(:,3)==1,1)));
utilityData = utilityData(ismember(utilityData(:,1),choiceSet),:);
schoolQuality = schoolQuality(ismember(schoolQuality(:,1),choiceSet),:);

%%Reading in school-level data
[B,newIndex] = sortrows(schoolQuality,1);
schoolQuality = schoolQuality(newIndex,:);
school_FRL = schoolQuality(:,2);
school_Black = schoolQuality(:,3);
school_Ability = schoolQuality(:,4);
school_susp = schoolQuality(:,5);

%%Reading in student/school-year level data
choiceRep = utilityData(:,1);
grade = utilityData(:,2);
indAttended = utilityData(:,3);
FRL = utilityData(:,4);
raceBlack = utilityData(:,5);
raceOther = utilityData(:,6);
moving_costs = utilityData(:,7);
drivingTimes = utilityData(:,8);
group = utilityData(:,9);
ability_index = utilityData(:,10);
ind_ability = utilityData(:,11);
net_income = utilityData(:,16);
gradeMin = utilityData(:,17);
gradeMax = utilityData(:,18);
randsid2 = utilityData(:,19);
magnetapplied = utilityData(:,20);
oversubscribed = utilityData(:,21);
everGifted = utilityData(:,22);
allSchools = utilityData(:,23);
female = utilityData(:,24);
inflowInd = utilityData(:,25);
ALAind = utilityData(:,26);
closedInd = utilityData(:,27);
everSpecEd = utilityData(:,28);
offenses = utilityData(:,29);
susp_days = utilityData(:,30);

%%Scaling net income
net_income = net_income/10000;

T = sum(choiceRep==92);
J = max(size(unique(choiceRep)));

response2 = choiceRep(indAttended==1);
responseMatrix = zeros(T,J);

A = unique(choiceRep);
for j=1:J
    responseMatrix(:,j) = (response2==A(j));
end

%%%Fix regressors to be TxJ each
net_income = reshape(net_income,J,T);
net_income = net_income';

raceBlack = reshape(raceBlack,J,T);
raceBlack = raceBlack';

FRL = reshape(FRL,J,T);
FRL = FRL';

ind_ability = reshape(ind_ability,J,T);
ind_ability = ind_ability';

travel_costs = reshape(drivingTimes,J,T);
travel_costs = travel_costs';

everGifted = reshape(everGifted,J,T);
everGifted = everGifted';

everSpecEd = reshape(everSpecEd,J,T);
everSpecEd = everSpecEd';

indAttended = reshape(indAttended,J,T);
indAttended = indAttended';

leaveInd = zeros(T,J);
leaveInd(:,J) = 1;

moving_costs = reshape(moving_costs,J,T);
moving_costs = moving_costs';

offenses = reshape(offenses,J,T);
offenses = offenses';

susp_days = reshape(susp_days,J,T);
susp_days = susp_days';

school_FRL = repmat(reshape(school_FRL,J,1),1,T);
school_FRL = school_FRL';

school_Black = repmat(reshape(school_Black,J,1),1,T);
school_Black = school_Black';

school_Ability = repmat(reshape(school_Ability,J,1),1,T);
school_Ability = school_Ability';

school_susp = repmat(reshape(school_susp,J,1),1,T);
school_susp = school_susp';

%Creating unavailable schools in a year
indUnavail = travel_costs==5000000;
travel_costs = travel_costs + (travel_costs==5000000) * (-5000000)+ (travel_costs==5000000)*(1.1*max(drivingTimes(drivingTimes~=5000000)));

%%Creating gradeMin and gradeMax to restrict the choice set
gradeMin(gradeMin==1) = 0;
gradeMinInd = (gradeMin>grade);
gradeMinInd = reshape(gradeMinInd,J,T);
gradeMinInd = gradeMinInd';

gradeMaxInd = (gradeMax<grade);
gradeMaxInd = reshape(gradeMaxInd,J,T);
gradeMaxInd = gradeMaxInd';

grade = reshape(grade,J,T);
grade = grade';

%%These variables aren't used in the current version of the estimation, but can be constructed and used if desired
privateInd=0;
school_Gifted=0;
school_SpecEd=0;

%Calculating negative log-likelihood and gradient for the conditional logit model
[negloglik,gradient] = condLogEst(gamma,responseMatrix,net_income,raceBlack,FRL,school_FRL,school_Black,school_Ability,ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,school_susp,T,J);

end