function [utilityData,schoolQuality,middle] = ind_exclude(utilityData);
%This script restricts the data to students in grades 6-8

%%Sorting the data:  VERY NECESSARY FOR THE RESHAPE TRICK I DO BELOW
[B,newIndex] = sortrows(utilityData,[9 1]);
utilityData = utilityData(newIndex,:);

%%Keeping only 6-8 grades
utilityData = utilityData(utilityData(:,2)>=6,:);

%%Only using choices that students attend
choiceSet = sort(unique(utilityData(utilityData(:,3)==1,1)));
utilityData = utilityData(ismember(utilityData(:,1),choiceSet),:);

%%Reading in student/school-choice level data
choiceRep = utilityData(:,1);
grade = utilityData(:,2);
indAttended = utilityData(:,3);
FRL = utilityData(:,4);
raceBlack = utilityData(:,5);
raceOther = utilityData(:,6);
moving_costs = utilityData(:,7);
drivingTimes = utilityData(:,8);
group = utilityData(:,9);
ability_index = utilityData(:,10);
ind_ability = utilityData(:,11);
net_income = utilityData(:,16);
gradeMin = utilityData(:,17);
gradeMax = utilityData(:,18);
randsid2 = utilityData(:,19);
magnetapplied = utilityData(:,20);
oversubscribed = utilityData(:,21);
everGifted = utilityData(:,22);
allSchools = utilityData(:,23);
female = utilityData(:,24);
inflowInd = utilityData(:,25);
ALAind = utilityData(:,26);
closedInd = utilityData(:,27);
everSpecEd = utilityData(:,28);
offenses = utilityData(:,29);
susp_days = utilityData(:,30);

T = sum(choiceRep==92);
J = max(size(unique(choiceRep)));

response2 = choiceRep(indAttended==1);
responseMatrix = zeros(T,J);

A = unique(choiceRep);
for j=1:J
    responseMatrix(:,j) = (response2==A(j));
end

%%%Fix regressors to be TxJ each
raceBlack = reshape(raceBlack,J,T);
raceBlack = raceBlack';

FRL = reshape(FRL,J,T);
FRL = FRL';

ind_ability = reshape(ind_ability,J,T);
ind_ability = ind_ability';

susp_days = reshape(susp_days,J,T);
susp_days = susp_days';

school_FRL= reshape(sum(FRL.*responseMatrix)./sum(responseMatrix),[J 1]);
school_Black= reshape(sum(raceBlack.*responseMatrix)./sum(responseMatrix),[J 1]);
school_Ability= reshape(sum(ind_ability.*responseMatrix)./sum(responseMatrix),[J 1]);
school_susp= reshape(sum(susp_days.*responseMatrix)./sum(responseMatrix),[J 1]);

%%Creating gradeMin and gradeMax to restrict the choice set
gradeMin(gradeMin==1) = 0;
gradeMin = reshape(gradeMin,J,T);
gradeMin = gradeMin';

gradeMax = reshape(gradeMax,J,T);
gradeMax = gradeMax';

middle = (gradeMin==6) & (gradeMax==8);

middle = reshape(middle(1,:),[J 1]);
schoolQuality = [reshape(A,[J 1]) school_FRL school_Black school_Ability school_susp ones(J,1) middle];

end