function W_char = obj_func_create_char(utilityData,gamma,beta_second_stage,residuals,schoolQuality,theta,capacity);
%%This script file calculates the "diversity" based objective function for a given sorting equilibrium (shadow prices, peer characteristics and schools closed)

%%Sorting the data:  VERY NECESSARY FOR THE RESHAPE TRICK I DO BELOW
[B,newIndex] = sortrows(utilityData,[9 1]);
utilityData = utilityData(newIndex,:);

%%Only using choices that students attend
choiceSet = sort(unique(utilityData(utilityData(:,3)==1,1)));
utilityData = utilityData(ismember(utilityData(:,1),choiceSet),:);

%%Reading in student/school-choice level data
choiceRep = utilityData(:,1);
grade = utilityData(:,2);
indAttended = utilityData(:,3);
FRL = utilityData(:,4);
raceBlack = utilityData(:,5);
raceOther = utilityData(:,6);
moving_costs = utilityData(:,7);
drivingTimes = utilityData(:,8);
group = utilityData(:,9);
ability_index = utilityData(:,10);
ind_ability = utilityData(:,11);
net_income = utilityData(:,16);
gradeMin = utilityData(:,17);
gradeMax = utilityData(:,18);
randsid2 = utilityData(:,19);
magnetapplied = utilityData(:,20);
oversubscribed = utilityData(:,21);
everGifted = utilityData(:,22);
allSchools = utilityData(:,23);
female = utilityData(:,24);
inflowInd = utilityData(:,25);
ALAind = utilityData(:,26);
closedInd = utilityData(:,27);
everSpecEd = utilityData(:,28);
offenses = utilityData(:,29);
susp_days = utilityData(:,30);

%%Scaling net income
net_income = net_income/10000;

T = sum(choiceRep==92);
J = max(size(unique(choiceRep)));

response2 = choiceRep(indAttended==1);
responseMatrix = zeros(T,J);

A = unique(choiceRep);
for j=1:J
    responseMatrix(:,j) = (response2==A(j));
end

%%%Fix regressors to be TxJ each
net_income = reshape(net_income,J,T);
net_income = net_income';

raceBlack = reshape(raceBlack,J,T);
raceBlack = raceBlack';

FRL = reshape(FRL,J,T);
FRL = FRL';

ind_ability = reshape(ind_ability,J,T);
ind_ability = ind_ability';

travel_costs = reshape(drivingTimes,J,T);
travel_costs = travel_costs';

everGifted = reshape(everGifted,J,T);
everGifted = everGifted';

everSpecEd = reshape(everSpecEd,J,T);
everSpecEd = everSpecEd';

indAttended = reshape(indAttended,J,T);
indAttended = indAttended';

leaveInd = zeros(T,J);
leaveInd(:,J) = 1;

grade = reshape(grade,J,T);
grade = grade';

susp_days = reshape(susp_days,J,T);
susp_days = susp_days';

%Creating unavailable schools in a year
indUnavail = travel_costs==5000000;
travel_costs = travel_costs + (travel_costs==5000000) * (-5000000)+ (travel_costs==5000000)*(1.1*max(drivingTimes(drivingTimes~=5000000)));

moving_costs = reshape(moving_costs,J,T);
moving_costs = moving_costs';

%%Creating gradeMin and gradeMax to restrict the choice set
gradeMin(gradeMin==1) = 0;
gradeMinInd = (gradeMin>grade);
gradeMinInd = reshape(gradeMinInd,J,T);
gradeMinInd = gradeMinInd';

gradeMaxInd = (gradeMax<grade);
gradeMaxInd = reshape(gradeMaxInd,J,T);
gradeMaxInd = gradeMaxInd';

gradeMin = reshape(gradeMin,J,T);
gradeMin = gradeMin';

gradeMax = reshape(gradeMax,J,T);
gradeMax = gradeMax';

%%These variables aren't used in the current version of the estimation, but can be constructed and used if desired
privateInd=0;
school_Gifted=0;
school_SpecEd=0;

J7 = J-7;

%%%Unpacking theta to obtain shadow prices, peer characteristics, and closed schools
shadow_price = theta(1:J);
school_FRL_new = reshape(theta(J + (1:J)),[1 J]);
school_Black_new = reshape(theta(2*J + (1:J)),[1 J]);
school_Ability_new= reshape(theta(3*J + (1:J)),[1 J]);
school_susp_new= reshape(theta(4*J + (1:J)),[1 J]);
weight_schools_mat = repmat(reshape([theta(5*J + (1:J7));ones(7,1)],[1 J]),[T 1]);


%%%Calculating conditional logit probability
probLogBaseline = condLogFull_closed(gamma,beta_second_stage,residuals,responseMatrix,net_income,raceBlack,FRL,repmat(school_FRL_new,[T 1]),repmat(school_Black_new,[T 1]),repmat(school_Ability_new,[T 1]),ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,repmat(school_susp_new,[T 1]),shadow_price,weight_schools_mat,T,J);

probLog = probLogBaseline;

school_FRL_new2 = sum(probLog.*FRL,1)./sum(probLog,1);
school_Black_new2 = sum(probLog.*raceBlack,1)./sum(probLog,1);
school_Ability_new2= sum(probLog.*ind_ability,1)./sum(probLog,1);
school_susp_new2= sum(probLog.*susp_days,1)./sum(probLog,1);

school_FRL_new2(isnan(school_FRL_new2)) = 0;
school_Black_new2(isnan(school_Black_new2)) = 0;
school_Ability_new2(isnan(school_Ability_new2)) = 0;
school_susp_new2(isnan(school_susp_new2)) = 0;

weighted_mean_FRL = sum(sum(probLog(:,1:J7).*FRL(:,1:J7).*weight_schools_mat(:,1:J7),1),2)/sum(sum(probLog(:,1:J7).*weight_schools_mat(:,1:J7),1),2);
weighted_mean_Black = sum(sum(probLog(:,1:J7).*raceBlack(:,1:J7).*weight_schools_mat(:,1:J7),1),2)/sum(sum(probLog(:,1:J7).*weight_schools_mat(:,1:J7),1),2);
weighted_mean_Ability = sum(sum(probLog(:,1:J7).*ind_ability(:,1:J7).*weight_schools_mat(:,1:J7),1),2)/sum(sum(probLog(:,1:J7).*weight_schools_mat(:,1:J7),1),2);
weighted_mean_susp = sum(sum(probLog(:,1:J7).*susp_days(:,1:J7).*weight_schools_mat(:,1:J7),1),2)/sum(sum(probLog(:,1:J7).*weight_schools_mat(:,1:J7),1),2);


d1 = mean(mean(FRL));
d2 = mean(mean(raceBlack));
d3 = mean(mean(abs(ind_ability)));
d4 = mean(mean(susp_days));

%%Want to minimize diversity-based objective function which is a weighted sum of:
W_char = sum((school_FRL_new2(1:J7)-weighted_mean_FRL).^2)./d1 + sum((school_Black_new2(1:J7)-weighted_mean_Black).^2)./d2 + sum((school_Ability_new2(1:J7)-weighted_mean_Ability).^2)./d3 + sum((school_susp_new2(1:J7)-weighted_mean_susp).^2)./d4;  %%Deviation from mean of school characteristics


end
