%%This script file does the following three things:
%(1) Find (one of) the sorting equilibrium associated with every possible school closing scenario where greater than 5% of public school capacity is closed and less than five schools are closed.  We also find a sorting equilibrium associated with the baseline scenario where no schools are closed.
%(2) Evaluate different objective functions (“Quality?, “Diversity?, “Retention?, and “Dislocation?) for each of these school closing scenarios.
%(3) For the school closing scenarios that optimize each of these different objective functions, this code constructs the summary statistics presented in Table 7, Table B.3, and Table B.4.


clc
clear

%%Setting file path and moving to that directory
path = 'D:/Dropbox/SCP/';
cd(strcat(path,'/code/optimal_school_closing/'));

%%Reading in data for all years: we only use students in grades 6-8 for the school year 2005 in the paper
utilityData04 =csvread(strcat(path,'/data/utilityData04.csv'),0,0);
utilityData05 =csvread(strcat(path,'/data/utilityData05.csv'),0,0);
utilityData06 =csvread(strcat(path,'/data/utilityData06.csv'),0,0);
utilityData07 =csvread(strcat(path,'/data/utilityData07.csv'),0,0);

%Restricting to students in grades 6-8
[utilityData04,schoolQuality042] = ind_exclude(utilityData04);
[utilityData05,schoolQuality052] = ind_exclude(utilityData05);
[utilityData06,schoolQuality062] = ind_exclude(utilityData06);
[utilityData07,schoolQuality072] = ind_exclude(utilityData07);

group04 = unique(sort(utilityData04(:,19)));
group05 = unique(sort(utilityData05(:,19)));
group06 = unique(sort(utilityData06(:,19)));
group07 = unique(sort(utilityData07(:,19)));

choiceSet04 = sort(unique(utilityData04(utilityData04(:,3)==1,1)));
choiceSet05 = sort(unique(utilityData05(utilityData05(:,3)==1,1)));
choiceSet06 = sort(unique(utilityData06(utilityData06(:,3)==1,1)));
choiceSet07 = sort(unique(utilityData07(utilityData07(:,3)==1,1)));

J04 = max(size(choiceSet04));
J05 = max(size(choiceSet05));
J06 = max(size(choiceSet06));
J07 = max(size(choiceSet07));
J = J04 + J05+J06+J07;

%%%Reading in Capacity Measure%%%
capacity = csvread(strcat(path,'/data/capacity_measure2.csv'),1,0);
capacity = sortrows(capacity,1);
capacity04 = capacity(ismember(capacity(:,1),choiceSet04),[1 2 3 4]);
capacity05 = capacity(ismember(capacity(:,1),choiceSet05),[1 2 5 6]);
capacity06 = capacity(ismember(capacity(:,1),choiceSet06),[1 2 7 8]);
capacity07 = capacity(ismember(capacity(:,1),choiceSet07),[1 2 9 10]);

capacity04(:,3) = capacity04(:,4)./capacity04(:,3);
capacity05(:,3) = capacity05(:,4)./capacity05(:,3);
capacity06(:,3) = capacity06(:,4)./capacity06(:,3);
capacity07(:,3) = capacity07(:,4)./capacity07(:,3);

capacity04(isnan(capacity04(:,3)),3) = 0;
capacity05(isnan(capacity05(:,3)),3) = 0;
capacity06(isnan(capacity06(:,3)),3) = 0;
capacity07(isnan(capacity07(:,3)),3) = 0;

capacity04 = capacity04(:,3).*capacity04(:,2);
capacity05 = capacity05(:,3).*capacity05(:,2);
capacity06 = capacity06(:,3).*capacity06(:,2);
capacity07 = capacity07(:,3).*capacity07(:,2);

capacity04(capacity04(:,1)==0) = 5e6;
capacity05(capacity05(:,1)==0) = 5e6;
capacity06(capacity06(:,1)==0) = 5e6;
capacity07(capacity07(:,1)==0) = 5e6;

capClosed = 0.05;

%%%Running first-stage conditional logit demand model separately for each school year
numreg = 23;
options=optimset('Algorithm','sqp','LargeScale','off','Display','iter','GradObj','on','MaxFunEvals',100000,'MaxIter',100000,'TolX',1e-10,'TolFun',1e-10,'DerivativeCheck','off','FinDiffType','central');
gamma04 = fminunc(@(gamma)dataread_est(utilityData04,gamma,schoolQuality042),zeros(numreg+J04,1),options);
gamma05 = fminunc(@(gamma)dataread_est(utilityData05,gamma,schoolQuality052),zeros(numreg+J05,1),options);
gamma06 = fminunc(@(gamma)dataread_est(utilityData06,gamma,schoolQuality062),zeros(numreg+J06,1),options);
gamma07 = fminunc(@(gamma)dataread_est(utilityData07,gamma,schoolQuality072),zeros(numreg+J07,1),options);

school_FE04 = gamma04((numreg+ 1):end);
school_FE05 = gamma05((numreg+ 1):end);
school_FE06 = gamma06((numreg+ 1):end);
school_FE07 = gamma07((numreg+ 1):end);

%%%Reading in feeder data
feedervar = csvread(strcat(path,'/data/feedervar68.csv'),1,0);

feedervar04 = feedervar(feedervar(:,1)==2004,:);
feedervar05 = feedervar(feedervar(:,1)==2005,:);
feedervar06 = feedervar(feedervar(:,1)==2006,:);
feedervar07 = feedervar(feedervar(:,1)==2007,:);

school_both04 = intersect(schoolQuality042(:,1),feedervar04(:,2));
school_both05 = intersect(schoolQuality052(:,1),feedervar05(:,2));
school_both06 = intersect(schoolQuality062(:,1),feedervar06(:,2));
school_both07 = intersect(schoolQuality072(:,1),feedervar07(:,2));

%%%%%%%Running second stage school quality fixed effects on school-level peer effects separately for each school year
y = [school_FE04(ismember(schoolQuality042(:,1),school_both04));school_FE05(ismember(schoolQuality052(:,1),school_both05));school_FE06(ismember(schoolQuality062(:,1),school_both06));school_FE07(ismember(schoolQuality072(:,1),school_both07))];
X = [schoolQuality042(ismember(schoolQuality042(:,1),school_both04),2:end);schoolQuality052(ismember(schoolQuality052(:,1),school_both05),2:end);schoolQuality062(ismember(schoolQuality062(:,1),school_both06),2:end);schoolQuality072(ismember(schoolQuality072(:,1),school_both07),2:end)];
Z = [[feedervar04(ismember(feedervar04(:,2),school_both04),3:6) schoolQuality042(ismember(schoolQuality042(:,1),school_both04),6:7)];[feedervar05(ismember(feedervar05(:,2),school_both05),3:6) schoolQuality052(ismember(schoolQuality052(:,1),school_both05),6:7)];[feedervar06(ismember(feedervar06(:,2),school_both06),3:6) schoolQuality062(ismember(schoolQuality062(:,1),school_both06),6:7)];[feedervar07(ismember(feedervar07(:,2),school_both07),3:6) schoolQuality072(ismember(schoolQuality072(:,1),school_both07),6:7)]];

beta_second_stage = tsls(y,X,Z);
beta_second_stage04 = beta_second_stage;
beta_second_stage05 = beta_second_stage;
beta_second_stage06 = beta_second_stage;
beta_second_stage07 = beta_second_stage;

residuals04 = school_FE04 - schoolQuality042(:,2:end)*beta_second_stage04;
residuals05 = school_FE05 - schoolQuality052(:,2:end)*beta_second_stage05;
residuals06 = school_FE06 - schoolQuality062(:,2:end)*beta_second_stage06;
residuals07 = school_FE07 - schoolQuality072(:,2:end)*beta_second_stage07;

%%%Calculating Baseline Probabilities Setting initial shadow prices = 0, Initial Peer Characteristics at Observed Levels, and all schools open%%%
thetaA = [zeros(J05,1);reshape(schoolQuality052(:,2),[J05 1]);reshape(schoolQuality052(:,3),[J05 1]);reshape(schoolQuality052(:,4),[J05 1]);reshape(schoolQuality052(:,5),[J05 1])];
[shadow_price,school_FRL_new2,school_Black_new2,school_Ability_new2,school_susp_new2] = dataread_NFP_closed_int_full(ones(1,J05),utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,capacity05,capClosed,thetaA);
thetaB = [reshape(shadow_price,[J05 1]);reshape(school_FRL_new2,[J05 1]);reshape(school_Black_new2,[J05 1]);reshape(school_Ability_new2,[J05 1]);reshape(school_susp_new2,[J05 1])];
probLogBaseline05 = dataread_NFP_closed_int_full2(ones(1,J05),utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,capacity05,capClosed,thetaA);


N = J05-7;

%%Creating Baseline Summary Statistics
weight_schools = ones(1,J05);
summary_temp = summary_stats_baseline(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,probLogBaseline05,weight_schools);
filename_sum = horzcat('summary_stats_','no_schools','_','baseline_05_68_four_schools.csv');
cd(strcat(path,'/results/'));
csvwrite(filename_sum,summary_temp)

%%%%%%Creating all possible combinations of school closings (up to four schools)
matCombinations4 = combnk([1:N],4);

matCombinations3 = combnk([1:N],3);
matCombinations3 = [matCombinations3 matCombinations3(:,1)];

matCombinations2 = combnk([1:N],2);
matCombinations2 = [matCombinations2 matCombinations2];

matCombinations1 = combnk([1:N],1);
matCombinations1 = [matCombinations1 matCombinations1 matCombinations1 matCombinations1];

matCombinations = [matCombinations4; matCombinations3; matCombinations2; matCombinations1];

numCombs = max(size(matCombinations));


index = [];

for i  = 1:numCombs
	tempMat = unique(matCombinations(i,:));
	indexflip=0;
	if(sum(capacity05(tempMat))>0.05*sum(capacity05(capacity05~=5e6)))
		combsize = max(size(tempMat))-1;
		if(combsize>0)
		for j = 1:combsize
			tempMat2 = combnk(tempMat,j);
			combsize2 = size(tempMat2,1);
			for k = 1:combsize2
			if(sum(capacity05(unique(tempMat2(k,:))))>0.05*sum(capacity05(capacity05~=5e6)))
				indexflip=1;
			end
			end
		end
		end
		if(indexflip==0)
			index = [index;i];
		end
	end
end

matCombinations = matCombinations(index,:);
numCombs = max(size(matCombinations));

%%Solving for the sorting equilibrium for each feasible school closing and evaluating each of our three objective functions
WMat_char= ones(numCombs,1)*1e8;
WMat_numOutsideOption= ones(numCombs,1)*1e8;
WMat_numClosed = ones(numCombs,1)*1e8;
tolMat=ones(numCombs,1)*1e8;

theta_store = cell(numCombs,1);

for i=1:numCombs
	tempMat = unique(matCombinations(i,:));
	if(sum(capacity05(tempMat))>0.05*sum(capacity05(capacity05~=5e6)))
		weight_schools = ones(1,J05);
		weight_schools(tempMat) = 0;

		[shadow_price,school_FRL_new2,school_Black_new2,school_Ability_new2,school_susp_new2,tol] = dataread_NFP_closed_int_full(weight_schools,utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,capacity05,capClosed,thetaB);
        tolMat(i)=tol;
		
        theta_temp = [reshape(shadow_price,[J05 1]);reshape(school_FRL_new2,[J05 1]);reshape(school_Black_new2,[J05 1]);reshape(school_Ability_new2,[J05 1]);reshape(school_susp_new2,[J05 1])];
		theta_temp = [theta_temp;reshape(weight_schools,[J05 1])];		
		theta_store{i} = theta_temp;
        
        W_numClosed = obj_func_create_numClosed(probLogBaseline05,theta_temp);
        W_numOutsideOption = obj_func_create_numOutsideOption(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,theta_temp,capacity05);
        W_char = obj_func_create_char(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,theta_temp,capacity05);
        WMat_char(i) = W_char;
        WMat_numOutsideOption(i) = W_numOutsideOption;
        WMat_numClosed(i) = W_numClosed;
	end
end

%%%%%Creating summary statistics for the post-closing sorting eqm. for the school closing scenarios that minimize each of our three objective functions
WMat = [WMat_char WMat_numOutsideOption WMat_numClosed];
obj_name = 'CHOONC';

for type=1:3
	[WMattemp,i] = min(WMat(:,type));
    theta_temp = theta_store{i};
	cd(strcat(path,'/code/optimal_school_closing/'));
    summary_temp = summary_stats(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,theta_temp);
    
	cd(strcat(path,'/results/'));
	filename_sum = horzcat('summary_stats_',obj_name((-1:0) + 2*type),'_',num2str(loopnum),'_05_68_four_schools.csv');
	csvwrite(filename_sum,summary_temp)	
    
    cd(strcat(path,'/code/optimal_school_closing/'));
    summary_temp = summary_stats_baseline(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,probLogBaseline05,theta_temp(5*J05 + (1:J05)));
	filename_sum = horzcat('summary_stats_',obj_name((-1:0) + 2*type),'_',num2str(loopnum),'baseline_05_68_four_schools.csv');

    cd(strcat(path,'/results/'));
    csvwrite(filename_sum,summary_temp)  

    cd(strcat(path,'/code/optimal_school_closing/'));
    summary_code0

    cd(strcat(path,'/code/optimal_school_closing/'));
    summary_code1
end


%%%%%%%%%%%Summary Statistics for the actual school closings after the 2005-06 school year%%%%%%%%%%%%%%
%%Reading in and constructing the predicted school rankings actually used to close down these schools
SPI_ranking = csvread(strcat(path,'/code/optimal_school_closing/ranking_data.csv'),0,0);
SPI_ranking = SPI_ranking(ismember(SPI_ranking(:,1),choiceSet05),:);
SPI_ranking = SPI_ranking(SPI_ranking(:,3)==1,[1 2]);
SPI_ranking = sortrows(SPI_ranking,1);

captoclose_worst = 0.05*sum(capacity05(capacity05~=5e6));

SPI_ranking2 = [SPI_ranking capacity05(ismember(choiceSet05,SPI_ranking(:,1)))];
SPI_ranking3 = sortrows(SPI_ranking2,2);
SPI_ranking_cum = [SPI_ranking3(:,1:2) cumsum(SPI_ranking3(:,3))];
closed_schools = SPI_ranking_cum(SPI_ranking_cum(:,3)<captoclose_worst,1);
index = sum(SPI_ranking_cum(:,3)<captoclose_worst);
closed_schools = [closed_schools;SPI_ranking_cum(index+1,1)];

weight_schools = ones(1,J05);
weight_schools(ismember(choiceSet05,closed_schools)) = 0;

cd(strcat(path,'/code/optimal_school_closing/'));
summary_temp = summary_stats_baseline(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,probLogBaseline05,weight_schools);
filename_sum = horzcat('summary_stats_','actual','_','baseline_05_68_four_schools.csv');
cd(strcat(path,'/results/'));
csvwrite(filename_sum,summary_temp)

cd(strcat(path,'/code/optimal_school_closing/'));
summary_temp = summary_stats(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,theta_temp);

cd(strcat(path,'/results/'));
filename_sum = horzcat('summary_stats_','actual','_','05_68_four_schools.csv');
csvwrite(filename_sum,summary_temp)

cd(strcat(path,'/code/optimal_school_closing/'));

%%%Creating summary statistics for actual school closings: setting peer characteristics corresponding to free or reduced lunch and proportion of Black students  = 1
thetaB2 = thetaB;
thetaB2(J05 + (1:J05)) = 1;
thetaB2(2*J05 + (1:J05)) = 1;

[shadow_price,school_FRL_new2,school_Black_new2,school_Ability_new2,school_susp_new2,tol] = dataread_NFP_closed_int(weight_schools,utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,capacity05,capClosed,thetaB2);
theta_temp = [reshape(shadow_price,[J05 1]);reshape(school_FRL_new2,[J05 1]);reshape(school_Black_new2,[J05 1]);reshape(school_Ability_new2,[J05 1]);reshape(school_susp_new2,[J05 1])];
theta_temp = [theta_temp;reshape(weight_schools,[J05 1])];

st = summary_stats(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,theta_temp);
stb = summary_stats_baseline(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,probLogBaseline05,theta_temp(5*J05 + (1:J05)));

cd(strcat(path,'/results/'));
filename_sum = horzcat('summary_stats_','actual','_','05_68_four_schools1.csv');
csvwrite(filename_sum,st)

filename_sum = horzcat('summary_stats_','actual','_','baseline_05_68_four_schools1.csv');
csvwrite(filename_sum,stb)

cd(strcat(path,'/code/optimal_school_closing/'));

%%%Creating summary statistics for actual school closings: setting peer characteristics corresponding to school proportion of students receiving free or reduced lunch and school-level proportion of Black students  = 0
thetaB2 = thetaB;
thetaB2(J05 + (1:J05)) = 0;
thetaB2(2*J05 + (1:J05)) = 0;

[shadow_price,school_FRL_new2,school_Black_new2,school_Ability_new2,school_susp_new2,tol] = dataread_NFP_closed_int(weight_schools,utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,capacity05,capClosed,thetaB2);
theta_temp = [reshape(shadow_price,[J05 1]);reshape(school_FRL_new2,[J05 1]);reshape(school_Black_new2,[J05 1]);reshape(school_Ability_new2,[J05 1]);reshape(school_susp_new2,[J05 1])];
theta_temp = [theta_temp;reshape(weight_schools,[J05 1])];

st = summary_stats(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,theta_temp);
stb = summary_stats_baseline(utilityData05,gamma05,beta_second_stage05,residuals05,schoolQuality052,probLogBaseline05,theta_temp(5*J05 + (1:J05)));

cd(strcat(path,'/results/'));
filename_sum = horzcat('summary_stats_','actual','_','05_68_four_schools0.csv');
csvwrite(filename_sum,st)

filename_sum = horzcat('summary_stats_','actual','_','baseline_05_68_four_schools0.csv');
csvwrite(filename_sum,stb)