function summary_data = summary_stats(utilityData,gamma,beta_second_stage,residuals,schoolQuality,theta);
%%This script file creates the summary statistics corresponding to a sorting equilibrium calculated for the school closing scenario
%The theta parameter consists of shadow prices, the post-closing sorting eqm. based peer characteristics (school prop. FRL, school prop. Black, school average achievement, school average number of suspensions) and vector of which schools are open versus closed


%%Sorting the data:  VERY NECESSARY FOR THE RESHAPE TRICK I DO BELOW
[B,newIndex] = sortrows(utilityData,[9 1]);
utilityData = utilityData(newIndex,:);

%%Only using choices that students attend
choiceSet = sort(unique(utilityData(utilityData(:,3)==1,1)));
utilityData = utilityData(ismember(utilityData(:,1),choiceSet),:);
schoolQuality = schoolQuality(ismember(schoolQuality(:,1),choiceSet),:);

%%Reading in school-level variables
[B,newIndex] = sortrows(schoolQuality,1);
schoolQuality = schoolQuality(newIndex,:);
school_FRL = schoolQuality(:,2);
school_Black = schoolQuality(:,3);
school_Ability = schoolQuality(:,4);
school_susp = schoolQuality(:,5);

%%Reading in student/school-choice level variables
choiceRep = utilityData(:,1);
grade = utilityData(:,2);
indAttended = utilityData(:,3);
FRL = utilityData(:,4);
raceBlack = utilityData(:,5);
raceOther = utilityData(:,6);
moving_costs = utilityData(:,7);
drivingTimes = utilityData(:,8);
group = utilityData(:,9);
ability_index = utilityData(:,10);
ind_ability = utilityData(:,11);
net_income = utilityData(:,16);
gradeMin = utilityData(:,17);
gradeMax = utilityData(:,18);
randsid2 = utilityData(:,19);
magnetapplied = utilityData(:,20);
oversubscribed = utilityData(:,21);
everGifted = utilityData(:,22);
allSchools = utilityData(:,23);
female = utilityData(:,24);
inflowInd = utilityData(:,25);
ALAind = utilityData(:,26);
closedInd = utilityData(:,27);
everSpecEd = utilityData(:,28);
offenses = utilityData(:,29);
susp_days = utilityData(:,30);

%%Scaling Net Income
net_income = net_income/10000;

T = sum(choiceRep==92);
J = max(size(unique(choiceRep)));

response2 = choiceRep(indAttended==1);
responseMatrix = zeros(T,J);

A = unique(choiceRep);
for j=1:J
    responseMatrix(:,j) = (response2==A(j));
end

%%%Fix regressors to be TxJ each
net_income = reshape(net_income,J,T);
net_income = net_income';

raceBlack = reshape(raceBlack,J,T);
raceBlack = raceBlack';

FRL = reshape(FRL,J,T);
FRL = FRL';

ind_ability = reshape(ind_ability,J,T);
ind_ability = ind_ability';

travel_costs = reshape(drivingTimes,J,T);
travel_costs = travel_costs';

everGifted = reshape(everGifted,J,T);
everGifted = everGifted';

everSpecEd = reshape(everSpecEd,J,T);
everSpecEd = everSpecEd';

indAttended = reshape(indAttended,J,T);
indAttended = indAttended';

leaveInd = zeros(T,J);
leaveInd(:,J) = 1;

grade = reshape(grade,J,T);
grade = grade';

offenses = reshape(offenses,J,T);
offenses = offenses';

susp_days = reshape(susp_days,J,T);
susp_days = susp_days';

moving_costs = reshape(moving_costs,J,T);
moving_costs = moving_costs';

%Creating unavailable schools in a year
indUnavail = travel_costs==5000000;
travel_costs = travel_costs + (travel_costs==5000000) * (-5000000)+ (travel_costs==5000000)*(1.1*max(drivingTimes(drivingTimes~=5000000)));

%%Creating gradeMin and gradeMax to restrict the choice set
gradeMin(gradeMin==1) = 0;
gradeMinInd = (gradeMin>grade);
gradeMinInd = reshape(gradeMinInd,J,T);
gradeMinInd = gradeMinInd';

gradeMaxInd = (gradeMax<grade);
gradeMaxInd = reshape(gradeMaxInd,J,T);
gradeMaxInd = gradeMaxInd';

gradeMin = reshape(gradeMin,J,T);
gradeMin = gradeMin';

gradeMax = reshape(gradeMax,J,T);
gradeMax = gradeMax';

%%These variables aren't used in the current version of the estimation, but can be constructed and used if desired
privateInd=0;
school_Gifted=0;
school_SpecEd=0;

%%Unpacking theta into the variables described at the top of the file
shadow_price = zeros(J,1);
school_FRL_new = reshape(theta(J + (1:J)),[1 J]);
school_Black_new = reshape(theta(2*J + (1:J)),[1 J]);
school_Ability_new= reshape(theta(3*J + (1:J)),[1 J]);
school_susp_new= reshape(theta(4*J + (1:J)),[1 J]);
weight_schools = reshape(theta(5*J + (1:J)),[1 J]);

%%Calculating conditional logit probability
probLog = condLogFull_closed(gamma,beta_second_stage,residuals,responseMatrix,net_income,raceBlack,FRL,repmat(reshape(school_FRL_new,[1 J]),[T 1]),repmat(reshape(school_Black_new,[1 J]),[T 1]),repmat(reshape(school_Ability_new,[1 J]),[T 1]),ind_ability,moving_costs,travel_costs,gradeMinInd,gradeMaxInd,gradeMin,gradeMax,indUnavail,privateInd,leaveInd,grade,everGifted,everSpecEd,susp_days,school_Gifted,school_SpecEd,repmat(reshape(school_susp_new,[1 J]),[T 1]),shadow_price,repmat(weight_schools,[T 1]),T,J);

sum(probLog,1)

%%Calculating the summary statistics listed in Table 7
summary_data = zeros(36,1);

index_public_open = (weight_schools==1) & ([1:J]<=(J-7));
summary_data(1) = sum(sum(probLog(:,index_public_open==1)));
summary_data(2) = mean(school_FRL_new(index_public_open==1));
summary_data(3) = mean(school_Black_new(index_public_open==1));
summary_data(4) = mean(school_Ability_new(index_public_open==1));
summary_data(5) = mean(school_susp_new(index_public_open==1));

summary_data(6) = std(school_FRL_new(index_public_open==1));
summary_data(7) = std(school_Black_new(index_public_open==1));
summary_data(8) = std(school_Ability_new(index_public_open==1));
summary_data(9) = std(school_susp_new(index_public_open==1));

index_public_closed = weight_schools==0;
summary_data(10) = sum(sum(probLog(:,index_public_closed==1)));
summary_data(11) = mean(school_FRL_new(index_public_closed==1));
summary_data(12) = mean(school_Black_new(index_public_closed==1));
summary_data(13) = mean(school_Ability_new(index_public_closed==1));
summary_data(14) = mean(school_susp_new(index_public_closed==1));

summary_data(15) = std(school_FRL_new(index_public_closed==1));
summary_data(16) = std(school_Black_new(index_public_closed==1));
summary_data(17) = std(school_Ability_new(index_public_closed==1));
summary_data(18) = std(school_susp_new(index_public_closed==1));

index_private = ([1:J]>(J-7));
summary_data(19) = sum(sum(probLog(:,index_private==1)));
summary_data(20) = mean(school_FRL_new(index_private==1));
summary_data(21) = mean(school_Black_new(index_private==1));
summary_data(22) = mean(school_Ability_new(index_private==1));
summary_data(23) = mean(school_susp_new(index_private==1));

summary_data(24) = std(school_FRL_new(index_private==1));
summary_data(25) = std(school_Black_new(index_private==1));
summary_data(26) = std(school_Ability_new(index_private==1));
summary_data(27) = std(school_susp_new(index_private==1));

index_OO = ([1:J]==J);
summary_data(28) = sum(sum(probLog(:,index_OO==1)));
summary_data(29) = mean(school_FRL_new(index_OO==1));
summary_data(30) = mean(school_Black_new(index_OO==1));
summary_data(31) = mean(school_Ability_new(index_OO==1));
summary_data(32) = mean(school_susp_new(index_OO==1));

summary_data(33) = std(school_FRL_new(index_OO==1));
summary_data(34) = std(school_Black_new(index_OO==1));
summary_data(35) = std(school_Ability_new(index_OO==1));
summary_data(36) = std(school_susp_new(index_OO==1));
end